defmodule DecentralisedBookIndexWeb.DbiServerLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  @impl true
  def render(assigns) do
    ~H"""
    <.header>
      Dbi server {@dbi_server.id}
      <:subtitle>This is a dbi_server record from your database.</:subtitle>

      <:actions>
        <.link patch={~p"/dbi_servers/#{@dbi_server}/show/edit"} phx-click={JS.push_focus()}>
          <.edit_button>
            Edit
          </.edit_button>
        </.link>
      </:actions>
    </.header>

    <.list>
      <:item title="Id">{@dbi_server.id}</:item>

      <:item title="Name">{@dbi_server.name}</:item>

      <:item title="Url">{@dbi_server.url}</:item>
    </.list>

    <.back navigate={~p"/dbi_servers"}>Back to dbi_servers</.back>

    <.modal
      :if={@live_action == :edit}
      id="dbi_server-modal"
      show
      on_cancel={JS.patch(~p"/dbi_servers/#{@dbi_server}")}
    >
      <.live_component
        module={DecentralisedBookIndexWeb.DbiServerLive.FormComponent}
        id={@dbi_server.id}
        title={@page_title}
        action={@live_action}
        current_user={@current_user}
        dbi_server={@dbi_server}
        patch={~p"/dbi_servers/#{@dbi_server}"}
      />
    </.modal>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :dbi_server,
       Ash.get!(DecentralisedBookIndex.Metadata.DBIServer, id, actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show Dbi server"
  defp page_title(:edit), do: "Edit Dbi server"
end
